### CHAPITRE 4 STARTING WITH DATAS

#how to load data
surveys <- read.csv("data/portal_data_joined.csv")
head(surveys)

#visualize with View()
View(surveys)

str(surveys)

#inspecting data frames

dim(surveys) #number of rows + columns
nrow(surveys)#number of rows
ncol(surveys)#number of columns

head(surveys) #1st 6 rows
tail(surveys) #last 6 rows

names(surveys) #names of columns (colnames() for data.frame)
rownames(surveys) #returns rows'names

str(surveys)
summary(surveys) #summary for each column

#QUESTION
#class of object surveys?
class(surveys) #its a data.frame 

#How many rows and how many columns are in this object?
ncol(surveys)
nrow(surveys)

#How many species (as defined by the species_id variable)
length(unique(surveys$species_id))

##indexing and subsetting data frames

#surveys[row,column]

# first element in the first column of the data frame (as a vector)
surveys[1, 1]
# first element in the 6th column (as a vector)
surveys[1, 6]
# first column of the data frame (as a vector)
surveys[, 1]
# first column of the data frame (as a data.frame)
surveys[1]
# first three elements in the 7th column (as a vector)
surveys[1:3, 7]
# the 3rd row of the data frame (as a data.frame)
surveys[3, ]
# equivalent to head_surveys <- head(surveys)
head_surveys <- surveys[1:6, ]

#we can exclude values using"-"

surveys[, -1]          # The whole data frame, except the first column
surveys[-c(7:34786), ] # Equivalent to head(surveys)

surveys["species_id"]       # Result is a data.frame
surveys[, "species_id"]     # Result is a vector
surveys[["species_id"]]     # Result is a vector
surveys$species_id          # Result is a vector

#QUESTION1
#data.frame (surveys_200) containing only the data in row 200 of the surveys dataset

surveys_200 <- surveys[200,]
surveys_200

#QUESTION2 Notice how nrow() gave you the number of rows in a data.frame?
#Use that number to pull out just that last row in the inital surveys data frame

nrow(surveys) #34786
last_row <- surveys[34786,]
last_row

#Compare that with what you see as the last row using tail()
tail(surveys)

#QUESTION3
#Use nrow() to extract the row that is in the middle of the surveys dataframe.
#Store the content of this row in an object named surveys_middle

n_rows <- nrow(surveys)
surveys_middle <- surveys[n_rows/2,]
surveys_middle

#QUESTION4
#Combine nrow() with the - notation above to reproduce the behavior of head(surveys),
# keeping just the first through 6th rows of the surveys dataset.

surveys_head <- surveys[-(7:n_rows), ]
surveys_head

##factors 

#By default, R always sorts levels in alphabetical order
sex <- factor(c("male", "female", "female", "male"))
levels(sex) #female is fisrt bc f is before m
nlevels(sex)
sex

#if we want a special order
sex <- factor(sex, levels = c("male", "female"))
sex ## after re-ordering

#converting to factors 
as.character(sex)

#renaming factors 
surv_sex <- factor(surveys$sex)
plot(surv_sex)

head(surv_sex)
levels(surv_sex)

levels(surv_sex)[1] <- "undetermined"  #we determine the NAs with a name 
levels(surv_sex)
head(surv_sex)

#QUESTION
#rename F and M to male and female + barplot 
levels(surv_sex)[2:3] <- c("female", "male")
surv_sex <- factor(surv_sex, levels = c("female", "male", "undetermined"))
plot(surv_sex)

##matrices
ip <- installed.packages()
dim(ip)
head(colnames(ip))
head(rownames(ip))

#is lubridate installed? 

## 1. get the names of all installed packages
ip <- rownames(installed.packages())
## 2. TRUE if installed, FALSE otherwise
"lubridate" %in% ip
# it is TRUE so it is installed

#how to construct a matrix
m <- matrix(1:9, ncol = 3, nrow = 3)
m

#QUESTION
#construct a matrix of dimension 1000 by 3 of normally distributed data

set.seed(123)
m1 <- matrix(rnorm(3000), ncol = 3)
dim(m1)
head(m1)

## formating dates
#we need lubridate for that 
library("lubridate")

my_date <- ymd("2015-01-01") #creating a date
str(my_date)

# sep indicates the character to use to separate each component
my_date <- ymd(paste("2015", "1", "1", sep = "-"))
str(my_date)

#character vector from the year, month, and day columns of surveys
head(paste(surveys$year, surveys$month, surveys$day, sep = "-"))

head(ymd(paste(surveys$year, surveys$month, surveys$day, sep = "-")))

#new column
surveys$date <- ymd(paste(surveys$year, surveys$month, surveys$day, sep = "-"))
head(surveys) #column "date" has been created
str(surveys)

summary(surveys$date) #sth went wrong, some dates have missing values
#we need to fix it 
is_missing_date <- is.na(surveys$date)
date_columns <- c("year", "month", "day")
missing_dates <- surveys[is_missing_date,  date_columns]
head(missing_dates)

## Lists : 1D, every item can be of a different data type 

l <- list(1:10, ## numeric
          letters, ## character
          installed.packages(), ## a matrix
          cars, ## a data.frame
          list(1, 2, 3)) ## a list
length(l)
#we created a list with differetn data types 
str(l)

#List subsetting is done using [] to subset a new sub-list
# or [[]] to extract a single element of that list

l[[1]] ## first element
l[1:2] ## a list of length 2
l[1]   ## a list of length 1

##exporting and saving datas

# to export the surveys data to the my_surveys.csv file in the data_output directory
write.csv(surveys, file = "data_output/my_surveys.csv")

#to save data as rda
save(surveys, file = "data_output/surveys.rda")
rm(surveys)
load("data_output/surveys.rda")
head(surveys)

#to save as RDS
saveRDS(surveys, file = "data_output/surveys.rds")
rm(surveys)
surveys <- readRDS("data_output/surveys.rds")
head(surveys)

##ADDITIONAL EXERCICES

#QUESTION1: Colony counting 

#vector named molds containing the results of your counts: 1, 2, 5, 8 and 10
molds <- c(1,2,5,8,10)
#vector days containing the week day, from Monday to Friday
days <- c("Monday","Tuesday","Wednesday","Thursday","Friday")
#create a data.frame named molds_study containing two variables Day and Molds_count.
molds_study <- data.frame("Day"= days,"Molds_count"= molds)
molds_study
class(molds_study)

#create a new data.frame that contains the observations where more than 2 colonies were counted
# How many observations are there? How many counts are there in total for these observations.

m2 <- molds_study$Molds_count > 2  #trouver obs avec >2 colonies
molds2 <- molds_study[m2,]         # créer le nouveau data.frame
molds2
nrow(molds2)                       # compter le nombre d'obs
sum(molds2$Molds_count)            # combien de colonies y comptons nous? 

#molds study experiment the next week and count the following nbrs of molds: 1, 6, 6, 5 and 4
#Add these data as a third column to the molds_study data.frame 
#and rename the variables as Day, Molds_1 and Molds_2

molds_2 <- c(1,6,6,5,4)
molds_study2 <- data.frame("Day"= days,"Molds_1"= molds, "Molds_2"=molds_2)
molds_study2


#Calculate for each experiment the total number of molds counted. 
# Check if the first experiment counted more molds than the second one

sum1 <- sum(molds_study2$Molds_1) 
sum2 <- sum(molds_study2$Molds_2)
sum1>sum2 #it returns TRUE so 1st experiment counted more molds 

#Save the molds_study variable in a file named molds_study.rda

save(molds_study, file = "data_output/molds_study.rda")

# QUESTION2 : beer consumption

#Using the beers.csv() function from rWSBIM1207, find the path the beers.csv file
# read it to produce a data.frame named beers.

library(rWSBIM1207)
beers <- read.csv(beers.csv())

#Use read.csv2() and read.delim() and set the separator appropriately, 
# and verify that the two variables are identical.

beers2 <- read.csv2(beers.csv())
beers2

#Check the number of observations and identify the variables that are available. 
#Calculate a summary of each variable using the summary function directly on the data.frame.

sum(beers2$Record_ID)
summary(beers2)

#Calculate the mean and the median age and consumption

mean(beers2$Age)
median(beers2$Age)
#OU
mean(beers2[,5])
median(beers2[,5])

#Do men consume more beer than women on average?

m <- beers2$Gender == "Male"     #extraire lignes correspondant aux hommes
beers2[m, "Consumption"]         # extraire consommation des hommes
mean(beers2[m, "Consumption"])   # moyenne 

f <- beers2$Gender == "Female"                 #extraire lignes correspondant aux femmes
beers2[f, "Consumption"]                       # extraire consommation des femmes
mean(beers2[f, "Consumption"], na.rm=TRUE)     # moyenne 

#Calculate a two-way table of gender and employment status.

genderXemployment <- table(beers2$Gender,beers2$Work)
genderXemployment

#Remove observations with missing values 
#export the data into a new csv file called beers_no_na.csv
library(dplyr)
beers_no_na <- beers2 %>% 
  na.omit

save(beers_no_na, file = "data_output/beers_no_na.csv")

#QUESTION3 : clinical

#Obtain the path to the csv file containing the clinical data need for this exercise
# using the clinical1.csv function and read it into R as a data.frame called clinical.

clinical <- read.csv(clinical1.csv())
class(clinical)

#Inspect the data using str and View. How many patients are recorded in the table

str(clinical)
View(clinical)
nrow(clinical)

#Print the column names using two different functions.

#?

#Create a smaller data frame called clinical_mini containing only the columns corresponding 
#to the patientID, gender, age_at_diagnosis and smoking_history

clinical_mini <- data_frame(clinical$patientID,clinical$gender,clinical$age_at_diagnosis,clinical$smoking_history)
View(clinical_mini)

library(tidyverse)
names(clinical_mini)[1] <- "patientID"
names(clinical_mini)[2] <- "gender"
names(clinical_mini)[3] <- "age_at_diagnosis"
names(clinical_mini)[4] <- "smoking_history"

View(clinical_mini)

#Inspect the smoking_history column. How many categories are recorded? 
#How many observations are there for each category?

tablesm<- table(clinical_mini$smoking_history)
length(unique(tablesm))

#The column age at diagnosis is recorded in days. 
#Create a new column years_at_diagnosis corresponding to the age at diagnosis converted in years

new_clinical_mini <- clinical_mini %>% 
  mutate(years_at_diagnosis = age_at_diagnosis/365)
View(new_clinical_mini)

#Calculate the mean and median age at diagnosis

mean(new_clinical_mini$years_at_diagnosis, na.rm=TRUE)
median(new_clinical_mini$years_at_diagnosis, na.rm=TRUE)

#Is there a difference between the years_at_diagnosis for male and female patients?

library(tidyverse)
male<- new_clinical_mini %>% 
  group_by(gender="male", na.rm=TRUE) 
mean(male$years_at_diagnosis, na.rm=TRUE)

female<- new_clinical_mini %>% 
  group_by(gender="female", na.rm=TRUE) 
mean(female$years_at_diagnosis, na.rm=TRUE)

#Use the quantile function to calculate the first and last quartile of age at diagnosis
?quantile
quantile(new_clinical_mini$years_at_diagnosis, na.rm=TRUE)

#Use the summary function to confirm your previous results.
summary(new_clinical_mini$years_at_diagnosis)





