### CHAPITRE 5 : MANIPULATING AND ANALYZING DATAS

library("tidyverse")

##2 WHAT ARE DPLYR AND TIDYR?

surveys <- read_csv("data/portal_data_joined.csv")
# inspect the data
str(surveys)
# preview the data
View(surveys)

#dplyr functions important

#select(): subset columns
#filter(): subset rows on conditions
#mutate(): create new columns by using information from other columns
#group_by() and summarize(): create summary statisitcs on grouped data
#arrange(): sort results
#count(): count discrete values

## 3 SELECTING COLUMNS AND FILTERING ROWS 

select(surveys, plot_id, species_id, weight) #To select some rows
select(surveys, -plot_id, -species_id, -weight) #to select all rows but three

#based on a specific criteria 
filter(surveys, year==1995)

## 4 PIPES : Pipes let you take the output of one function and send it directly to the next

surveys %>%
  filter(weight < 5) %>%
  select(species_id, sex, weight)

#we can assign them a name
surveys_sml <- surveys %>%
  filter(weight < 5) %>%
  select(species_id, sex, weight)

surveys_sml

#QUESTION 
surveys %>%
  filter(year < 1995) %>%
  select(year, sex, weight)

##5 MUTATE 
# To create a new column based on a old column

surveys %>%
  mutate(weight_kg = weight / 1000)

#or a second column based on the 1st new column 

surveys %>%
  mutate(weight_kg = weight / 1000,
         weight_kg2 = weight_kg * 2)

#to only see the 1st 6 rows
surveys %>%
  mutate(weight_kg = weight / 1000) %>%
  head()

# to remove NAs from weight for example
surveys %>%
  filter(!is.na(weight)) %>%
  mutate(weight_kg = weight / 1000) %>%
  head()

#QUESTION
#new data frame from the surveys data that meets the following criteria: 
#contains only the species_id column and a new column called hindfoot_half 
#containing values that are half the hindfoot_length values. In this hindfoot_half column
#there are no NAs and all values are less than 30.

surveys_hindfoot_half <- surveys %>%
  filter(!is.na(hindfoot_length)) %>%
  mutate(hindfoot_half = hindfoot_length / 2) %>%
  filter(hindfoot_half < 30) %>%
  select(species_id, hindfoot_half)
surveys_hindfoot_half

#6 SPLIT APPLY COMBINE DATA ANALYSIS 

surveys %>% 
  group_by(sex)

#often group_by is used with summarize, so we can have a proper tibble 

surveys %>% 
  group_by(sex) %>%
  summarize(mean_weight=mean(weight,na.rm=TRUE))

#we can group by multiple columns

surveys %>%
  group_by(sex, species_id) %>%
  summarize(mean_weight = mean(weight, na.rm = TRUE))

#to withdraw NaN
surveys %>%
  filter(!is.na(weight)) %>%
  group_by(sex, species_id) %>%
  summarize(mean_weight = mean(weight))

#print() function at the end of your chain with armt n specifying the nbr of rows to display
surveys %>%
  filter(!is.na(weight)) %>%
  group_by(sex, species_id) %>%
  summarize(mean_weight = mean(weight)) %>%
  print(n = 15)

#summarize multiple variables at the same time
surveys %>%
  filter(!is.na(weight)) %>%
  group_by(sex, species_id) %>%
  summarize(mean_weight = mean(weight),
            min_weight = min(weight))

#we can arrange, here for exemple by weight 
surveys %>%
  filter(!is.na(weight)) %>%
  group_by(sex, species_id) %>%
  summarize(mean_weight = mean(weight),
            min_weight = min(weight)) %>%
  arrange(min_weight)

# to sort in descending order, we can add desc()
surveys %>%
  filter(!is.na(weight)) %>%
  group_by(sex, species_id) %>%
  summarize(mean_weight = mean(weight),
            min_weight = min(weight)) %>%
  arrange(desc(mean_weight))

# we can count the nmbr of observations for each sex 
surveys %>%
  count(sex)

#count() provides the sort argument
surveys %>%
  count(sex, sort = TRUE)

#to count combination of factors
surveys %>% 
  count(sex,species)

# species in alphabetical order, and in descending order of the count
surveys %>%
  count(sex, species) %>%
  arrange(species, desc(n))

#QUESTION
#How many animals were caught in each plot_type surveyed?
surveys %>% 
  count(plot_type)

#Use group_by() and summarize() to find the mean, min, and max hindfoot length 
#for each species (using species_id). Also add the number of observations

surveys %>%
  filter(!is.na(hindfoot_length)) %>% 
  group_by(species) %>%
  summarize(mean_hindfoot = mean(hindfoot_length),
            min_hindfoot = min(hindfoot_length),
            max_hindfoot = max(hindfoot_length),
            n=n())

#What was the heaviest animal measured in each year? 
#Return the columns year, genus, species_id, and weight

surveys %>%
  filter(!is.na(weight)) %>%
  group_by(year) %>%
  filter(weight==max(weight)) %>%
  select(year,genus,species_id,weight) %>%
  arrange(year)

#7 RESHAPING DATA

#pivoting in wider format 
#the names_from column name whose values will become new column names
#the values_from column name whose values will fill the new columns

#Let’s use pivot_wider() to transform surveys to find the mean weight of each species 
#in each plot over the entire survey period
surveys_gw <- surveys %>%
  filter(!is.na(weight)) %>%
  group_by(genus, plot_id) %>%
  summarize(mean_weight = mean(weight))
surveys_gw

surveys_wide <- surveys_gw %>%
  pivot_wider(names_from = genus,
              values_from = mean_weight)
surveys_wide

#we can transform NA as "0"
surveys_gw %>%
  pivot_wider(names_from = genus,
              values_from = mean_weight,
              values_fill = 0)

#pivoting in wider format 
#the new names_to column we wish to create and populate with the current column names
#the new values_to column we wish to create and populate with current values
#the names of the columns to be used to populate the names_to & values_to variables (or to drop)

#recreate surveys_gw from surveys_wide

surveys_long <- surveys_wide %>%
  pivot_longer(names_to = "genus",
               values_to = "mean_weight",
               -plot_id)
surveys_long

#arrange the data by plot_id:
surveys_wide %>%
  pivot_longer(names_to = "genus",
               values_to = "mean_weight",
               -plot_id) %>%
  arrange(plot_id)

#specification for what columns to include with ":"
surveys_wide %>%
  pivot_longer(names_to = "genus",
               values_to = "mean_weight",
               Baiomys:Spermophilus)

#re-arrange the data
surveys_wide %>%
  pivot_longer(names_to = "genus",
               values_to = "mean_weight",
               Baiomys:Spermophilus) %>%
  arrange(genus, plot_id)

#QUESTION
rich_time <- surveys %>%
  group_by(plot_id, year) %>%
  summarize(n_genera = n_distinct(genus)) %>%
  pivot_wider(names_from = "year",
              values_from = "n_genera")
head(rich_time)

#data frame and transform it with pivot_longer() 
#so each row is a unique plot_id by year combination

rich_time %>%
  pivot_longer(names_to = "year",
               values_to = "n_genera",
               -plot_id)
#use pivot_longer() to create a dataset where we have a key column called measurement 
#and a value column that takes on the value of either hindfoot_length or weight
surveys_long <-
  surveys %>%
  pivot_longer(
    names_to = "measurement",
    values_to = "value",
    c(hindfoot_length, weight))
surveys_long

#calculate the average of each measurement in each year for each different plot_type. 
#Then use pivot_wider() to generate a data set with a column for hindfoot_length and weight

surveys_long %>%
  group_by(year, measurement, plot_type) %>%
  summarize(mean_value = mean(value, na.rm=TRUE)) %>%
  pivot_wider(names_from = "measurement",
              values_from = "mean_value")

## 8 EXPORTING DATAS 

surveys_complete <- surveys %>%
  filter(!is.na(weight),           ## remove missing weight
         !is.na(hindfoot_length),  ## remove missing hindfoot_length
         !is.na(sex))              ## remove missing sex
surveys_complete

## Extract the most common species_id
species_counts <- surveys_complete %>%
  count(species_id) %>%
  filter(n >= 50)
species_counts
## Only keep the most common species
surveys_complete <- surveys_complete %>%
  filter(species_id %in% species_counts$species_id)
surveys_complete

write_csv(surveys_complete, path = "data_output/surveys_complete.csv")

##ADDITIONNAL EXERCISES 

#1
library(rWSBIM1207)
data(beers)
#remove NAs
beers_no_na<- beers %>%
  filter(!is.na(beers))
#new column date
library(lubridate)
library(dplyr)
library(tidyverse)
beers_no_na %>%
  mutate(Date = ymd(paste(Year,Month,Day)))

#new table, containing obs for women older than 35 year, employed, and select all cols except 
#Day, Month and Year, and order in descending value of consumption of beers

new_obs_beers<- beers_no_na %>%
  filter(Gender=="Female",Age>35,Work=="Employed") %>%
  select(-Day,-Month,-Year) %>%
  arrange(desc(Consumption))

#export to a new csv files

write_csv(new_obs_beers, path = "data_output/new_obs_beers.csv")

#Does employment status have an impact on beer consumption

beers_no_na %>%
  group_by(Work) %>%
  summarize(Mean_Consumption= mean(Consumption,na.rm=TRUE))

#Do men drink more than women?
beers_no_na %>%
  group_by(Gender) %>%
  summarize(mean_cons = mean(Consumption, na.rm = TRUE))

#Does employment status have an influence on beer consumption according to gender?

beers_no_na %>%
  group_by(Gender,Work) %>%
  summarize(mean_cons = mean(Consumption, na.rm = TRUE))
#2
library("rWSBIM1207")
clinical1<- read_csv(clinical1.csv())

#create a df
clinical<- data_frame(clinical1)
clinical
class(clinical)

#maller data frame called clinical_mini containing only the columns corresponding to 
#patientID, gender, age_at_diagnosis, smoking_history, 
#number_pack_years_smoked, year_of_tobacco_smoking_onset, and stopped_smoking_year.

clinical_mini <- clinical %>%
  select(patientID,gender,age_at_diagnosis,smoking_history,
         number_pack_years_smoked,year_of_tobacco_smoking_onset,stopped_smoking_year)
clinical_mini

#Calculate the number of males and females in the cohort.

clinical_mini %>%
  group_by(gender) %>%
  count(gender)

#new variable years_at_diagnosis corresponding to the age at diagnosis converted from days into years

clinical_mini2 <- clinical_mini %>%
  mutate(years_at_diagnosis = age_at_diagnosis/365)
head(clinical_mini2)

#mean and median age at diagnosis (in years)

clinical_mini2 %>%
  summarize(meanyear = mean(years_at_diagnosis, na.rm=TRUE),
            medianyear = median(years_at_diagnosis,na.rm=TRUE))

#Calculate the mean and median age at diagnosis for males and females

clinical_mini2 %>%
  group_by(gender) %>%
  summarize(meanyear = mean(years_at_diagnosis, na.rm=TRUE),
            medianyear = median(years_at_diagnosis,na.rm=TRUE))

#How many patient were diagnosed before 50 years?
clinical_mini2 %>%
  filter(years_at_diagnosis<50) %>%
  count()

#Compare the mean age at diagnosis between current smoker and lifelong non-smoker.
clinical_mini2 %>%
  group_by(smoking_history) %>%
  summarize(meanAge = mean(years_at_diagnosis, na.rm = TRUE))

#select patients who stopped smoking >15 yrs ago &calculate the nbr of smoking yrs for these cases.

clinical %>%
  filter(stopped_smoking_year<2006, !is.na(stopped_smoking_year)) %>% 
  mutate(number_of_smoking_years = stopped_smoking_year-year_of_tobacco_smoking_onset) %>% 
  filter(!is.na(number_of_smoking_years))

# how many of them smokes less than 5 years?

clinical %>%
  filter(stopped_smoking_year<2006, !is.na(stopped_smoking_year)) %>% 
  mutate(number_of_smoking_years = stopped_smoking_year-year_of_tobacco_smoking_onset) %>% 
  filter(!is.na(number_of_smoking_years)) %>%
  filter(number_of_smoking_years<5) %>%
  count()

#recreate the tibble

clinictable <- clinical%>%
  select(smoking_history, gender)%>%
  filter(smoking_history %in% c("current smoker", "lifelong non-smoker"))
table(clinictable)

#3
interroA <- read_csv(interroA.csv())
longer <- interroA %>%
  pivot_longer(cols = c(interro1, interro2, interro3, interro4),
               names_to= "interros", values_to = "results")
longer

interro_long<- interroA %>% 
  pivot_longer(names_to = "interro",
               values_to = "res",
               c(interro1, interro2, interro3, interro4))
interro_long

