### CHAPITRE 7 JOINING TABLES

## 1 Combining tables

library("rWSBIM1207")
data(jdf)
jdf1 #with acesssion nbr + organelle + entry
jdf2 #with description of the gene + accession nbr + species the prot comes from

#to joint those two tables we need "dplyr", it will be joined thanks to uniprot 
library("dplyr")
full_join(jdf1,jdf2)

#in case none of the names match, we can set them manually using the by argument
#jdf1 and jdf3 have, for example, different names for uniprot 

names(jdf3) #here it is "UniProt", and jdf1 is "uniprot"
full_join(jdf1, jdf3, by = c("uniprot" = "UniProt"))

#QUESTION
#Using the full_join function demonstrated above, join tables jdf4 and jdf5.
#What has happened for observations P26039 and P02468?

names(jdf4)
names(jdf5)
#they both have same name for "uniprot"
full_join(jdf4,jdf5)
#P02468 and P02468 are only present in jdf4 and jdf5 respectively
#and their respective values for the variables of the table have been encoded as missing.

## 2 Different types of joins

# An inner join keeps observations that are present in both tables.
#A left join keeps observations that are present in the left (first) table
#dropping those that are only present in the other.
#A right join keeps observations that are present in the right (second) table
#dropping those that are only present in the other.
#A full join keeps all observations.

#questions

#Join tables jdf4 and jdf5, keeping only observations in jdf4.

left_join(jdf4,jdf5)

# Join tables jdf4 and jdf5, keeping only observations in jdf5.

right_join(jdf4,jdf5)

#Join tables jdf4 and jdf5, keeping only observations in jdf5.

full_join(jdf4,jdf5)

## 3 multiple matches 

# jdf6 -> the accession number Q99PL5 is repeated twice

jdf6

#If we now want to join jdf6 and jdf2, the variables of the latter will be duplicated.
full_join(jdf6,jdf2)

#repeating can be helpful
inner_join(jdf6,jdf7)


## 4 Matching accross multiple keys

#sometimes we need to match by mutliples keys b
inner_join(jdf6, jdf7, by = c("uniprot" = "uniprot", "isoform" = "isoform_num"))

# question : Can you think of another way to merge tables jdf6 and jdf7 using the two keys?

i <- grep("isoform", names(jdf7))
names(jdf7)[i] <- "isoform"
inner_join(jdf6, jdf7)

## 5 row and column binding 

#first we have to create the dataframe
x <- c(1,2,3)
y <- c(1,2,3)
d1 <- data.frame(x,y)

a <- c(4,5)
b <- c(4,5)
d2 <- data.frame(a,b)

#col names arent the same so there is a error if we do this : 
try(rbind(d1,d2))

#so now we know that we have ti match de col names before rbinding 

names(d2) <- names(d1)
rbind(d1, d2)

# If we want to bind to dataframes along their columns
cbind(d2, d3) 

#rbind dataframes with identical column names but different variables
#which end up all being coerced into characters
d4 <- data.frame(x = letters[1:2], y = letters[1:2])
str(rbind(d1, d4))

## 6 Additional exercises 

#1 : Using the jdf4 and jdf5 tables, emulate the left, right and inner joins 
# using a the full join and filter functions.

full_join(jdf4,jdf5) %>%
  filter(!is.na(jdf4,jdf5))

#2

#1st, we have to load the packages and datas
library(rWSBIM1207)
data("clinical2")
data("expression")

#Inspect the expression data. How many samples are recorded?

str(expression)

expression %>%
  count(sampleID)

# Join the expression and clinical2 tables by the patient reference
# using the left_join and the right_join functions. Why are the results different?

names(clinical2)
names(expression)
head(clinical2)
head(expression)
#we have to join by the patientID and patient names
full_join(clinical2,expression, by = c("patientID" = "patient"))


#Join expression and clinical2 tables in order to create a table containing
#merged data exclusively for normal samples.

expression_norm <- expression %>% 
  filter(type == "normal")

expression_norm
inner_join(clinical2, expression_norm, by = c("patientID" = "patient"))
