### CHAPITRE 9 : BIOINFORMATICS

# 4 : Omics data containers 

library("SummarizedExperiment")
library("rWSBIM1322")
data(cptac_se)
class(cptac_se)

cptac_se
#The object contains data for4051 features (peptides in this case) and 6 samples.
dim(cptac_se)
nrow(cptac_se) #4051
ncol(cptac_se) #6

#names: 
colnames(cptac_se)
head(rownames(cptac_se))
tail(rownames(cptac_se))

# for the head of the assay
head(assay(cptac_se))
head(rowData(cptac_se))
colData(cptac_se)
#The nNA variables above indicate the number of missing values 

# Question : Verify that the expression data dimensions match with number 
# of rows and columns in the feature and sample data.

cptac_se2 <- cptac_se[c(1, 3, 5), c(2, 4)]
dim(cptac_se2)

head(assay(cptac_se2))

colData(cptac_se)$group2  <- rep(c('X', 'Y', 'Z'), each = 2)
colData(cptac_se)

## ADDITIONAL EXERCISES 

# Extract the quantitative information for the peptides AIGVLPQLIIDR, NLDAAPTLR and
#YGLNHVVSLIENKK for samples 6A_7 and 6B_8.Subsetting works as we have seen in chapter 3.

colnames(cptac_se)
cptac_se3 <- cptac_se[c("AIGVLPQLIIDR", "NLDAAPTLR","YGLNHVVSLIENKK"),c(1,5)]
cptac_se3
assay(cptac_se3)

# Look and interpret the experimental design stored in the sample metadata of this experiment.
metadatac <- colData(cptac_se)
metadatac

# What is the average expression of LSAAQAELAYAETGAHDK in the groups 6A and 6B?

mean(assay(cptac_se)["LSAAQAELAYAETGAHDK",1:3])
mean(assay(cptac_se)["LSAAQAELAYAETGAHDK",4:6])

#Calculate the average expression of all peptides belonging to protein 
#P02753ups|RETBP_HUMAN_UPS for each sample.
#You can indentify which peptides to use by looking for that protein in the object rowData slot

rowData(cptac_se)
avg <- rowData(cptac_se)$Proteins== "P02753ups|RETBP_HUMAN_UPS"
min(which(avg == TRUE))
which(avg == TRUE)

pp <- cptac_se[c(2742,4048)]
pp
app <- assay(pp)
mean(app)

## exo with Kem

# 2 : Import the data from two tab-separated files into R. 
#The full paths to the two files can be accessed with kem.tsv()
#Read the data into two tibbles names kem and annot respectively 

library(tidyverse)
read_tsv(kem.tsv())

kem <- read_tsv("/usr/local/lib/R/site-library/rWSBIM1207/extdata/kem_counts.tsv")
annot <- read_tsv("/usr/local/lib/R/site-library/rWSBIM1207/extdata/kem_annot.tsv")
annot

# 3 : Convert the counts data into a long table format 
# and annotate each sample using the experimental design.

kem_long <- kem %>%
  pivot_longer(!ref, names_to = "sample_ID", values_to = "gene_expression")

kem_long


# 4 : Identity the three transcript identifiers that have the highest 
# expression count over all samples.

kem_long%>%
  top_n(3, counts)

# 5 : Visualise the distribution of the expression for the three transcripts selected 
# above in cell types A and B under both treatments.

library(dplyr)
library(tidyverse)

kem_long <- kem%>% 
  pivot_longer(names_to = "sample_id", values_to="gene_expression",-ref)

kem_long

full_join(kem_long, annot) %>%
  group_by(ref) %>% summarise(counts=sum(gene_expression)) %>%
  arrange(desc(counts))

full_join(kem_long, annot) %>%
  filter(ref %in% c("ENSG00000198804","ENSG00000198712","ENSG00000109971")) %>%
  ggplot(aes(x=treatment, y= gene_expression)) +
  geom_boxplot() +
  geom_jitter()+
  facet_grid(ref~cell_type)

# 6 For all genes, calculate the mean intensities in each experimental group
# (as defined by the cell_type and treatment variables).


 full_join(kem_long, annot) %>%
  group_by(cell_type,treatment,ref) %>%
  summarise(m=mean(gene_expression))

 
# 7 : Focusing only on the three most expressed transcripts and cell type A,
# calculate the fold-change induced by the treatment.
# The fold-change is the ratio between the average expressions in two conditions.

kem_long_annot <- full_join(kem_long, annot)

kem_long_annot2 <- kem_long_annot%>%
  select(ref, cell_type, sample_id, gene_expression, treatment) %>% 
  filter(ref %in% c("ENSG00000198804", "ENSG00000198712", "ENSG00000109971"),
         cell_type == "A")

kem_long_annot2

kem_long_annot2 %>% 
  na.omit() %>% 
  group_by(sample_id) %>% 
  pivot_wider(names_from = "treatment",
              values_from = "gene_expression",
              c(ref, cell_type, sample_id))

## Question 3 

#load data se.rds

se <- read_rds("data/se.rds")
se

# Explore the object’s colData and interprete it as the data’s experimental design.

colData(se)

# Generate a figure similar to the one below for your data own data. (cfr)

t <- as_tibble(cbind(assay(se),rowData(se))) %>% 
  pivot_longer(names_to = "samples",values_to="gene_expression", -c(gene,location)) 

t

full_join(as_tibble(colData(se)),t) %>% 
  filter(gene %in% c("Gene1","Gene2","Gene3")) %>%  
  ggplot(aes(x=group, y= gene_expression)) + geom_boxplot()+ facet_wrap(~gene)

full_join(as_tibble(colData(se)),t) %>% 
  ggplot(aes(x=group, y= gene_expression)) + geom_boxplot()+ facet_wrap(~gene)


# Calculate the average expression for each gene in each group.

#?

#
