## ITERATION

(x <- 1:10)

#-> LOOP


for (i in x) {
  print(log(i))
}

res_loop <- rep(NA, length(x))
for (i in seq_along(x)) {
  res_loop[i] <- log(x[i])
}
res_loop

#-> APPLY FUNCTION "For each value of my input x, apply log"

res_apply <- sapply(x, log)
res_apply

#sapply iterates over a vector 
#lapply iterates over a linear input 
#apply iterates of the rows or the columns of a data.frame or a matrix

#verifify theyre the the same

identical(res_apply,res_loop)
#it returns to be TRUE, then it is identical

#vectorisation, by default there is an iteration
res_vec <- log(x)
res_vec

identical(res_vec,res_apply,res_loop)
#it returns to be TRUE, so we know that theyre all the same again.

###QUESTION
library("tidyverse")
library("rWSBIM1207")
fls <- expressions.csv()
read_csv(fls[1])
read_csv(fls[2])
#combine in on single dataframe, We see that the data will have to be combined column-wise

# read the first one
res <- read_csv(fls[1])
# iterate over the other data
for (i in 2:length(fls)) {
  data_i <- read_csv(fls[i], progress = FALSE)
  res <- full_join(res, data_i)
}
res

## CONDITIONALS

if (CONDITION) {
  ## DO SOMETHING
} else {
  ## DO SOMETHING ELSE
}

(x <- rnorm(1))

if (x > 0) {
  print(log(x))
} else {
  print(log(-x))
}

#works with vectors too
x <- rnorm(10)
log(abs(x))

#if_else(condition, true, false)
x <- 0.5
if_else(x > 0, 1, 0)

# condition can be a vector of length greater than 1
x <- rnorm(10)
x
if_else(x > 0, 1, 0)
#when its negative, we have a 0, otherwise its a 1 (when positive)

#In a standard data analysis pipeline 
x <- tibble(x = LETTERS[1:5],
            y = rnorm(5))
x
mutate(x, z = if_else(y > 0, 1, 0)) #ADDING a column with MUTATE, when negative-> 0, otherwise 1

##WRITING NEW FUNCTIONS

my_fun <- function(x, y) {
  message("First input: ", x)
  message("Second input: ", y)
  z <- x * abs(y)
  return(z)
}
my_fun(2, -5)

###QUESTION

fun <- function(x, y) {
  res <- NA
  if (x>y) {
    res <- sample(x,y)
  } else {
    res <- rnorm(1000,x,y)
  }
  return(sum(res))
}
fun

set.seed(1L)
fun(5, 15)

set.seed(1L)
fun(15, 5)

##PATTERN MATCHING

library("rWSBIM1207")
data(peptides)
length(peptides)

head(peptides)

pattern <- "AAGE"
grep(pattern,peptides) #to find which one of the peptides contains "AAGE"

grep(pattern, peptides, value = TRUE) #to see the peptides with the "AAGE"

head(grepl(pattern, peptides)) #to see if there localized in the head 

##replace
head(sub("AE", "XX", peptides)) #AE becomes XX
head(sub("A", "X", peptides)) #A becomes X (only the first A)
head(gsub("A", "X", peptides)) #All As becomes Xs, no more only the first one

##ANALYZING DATA FROM MULTIPLE FILES 

#1 : load the packages
library("rWSBIM1207")
library("tidyverse")

#2 : interroA and interroB functions to create a vector containing the two csv file names.
fls <- c(interroA.csv(),
         interroB.csv())
fls

#3 : Iterate over the files and read each into an element of a list.
#Then, bind the two elements of the list into a single dataframe containing all results

l <- as.list(fls) #make a list out of two files
for (i in seq_along(fls))
  l[[i]] <- read_csv(fls[i])

interros <- rbind(l[[1]], l[[2]]) #bindinds the two elemenst into a dataframe 
interros

dim(interros)


##autre technique 

l <- lapply(fls, read_csv)
interros2 <- rbind(l[[1]], l[[2]])

identical(interros,interros2) #it the returns to the same 

#4 : mean scores for male and female students in each test (interro1 to interro4)

interros %>%
  group_by(gender) %>% #to separate M and F
  summarise(m1 = mean(interro1, na.rm = TRUE),
            m2 = mean(interro2, na.rm = TRUE),
            m3 = mean(interro3, na.rm = TRUE),
            m4 = mean(interro4, na.rm = TRUE)) 

#5 : mean scores for male and female students in each test and in each group.

l[[1]]$group <- "A"
l[[2]]$group <- "B"
interros3 <- rbind(l[[1]], l[[2]])

interros3 %>%
  group_by(gender, group) %>%
  summarise(m1 = mean(interro1, na.rm = TRUE),
            m2 = mean(interro2, na.rm = TRUE),
            m3 = mean(interro3, na.rm = TRUE),
            m4 = mean(interro4, na.rm = TRUE))

#6 : visualise distributions using boxplots,  overlay the actual score values (with jitter geom) 
#and colour the points based on the students height.

#we need to convert in a long format
interros4 <- pivot_longer(interros3,
                          names_to = "test",
                          values_to = "score",
                          starts_with("interro"))
interros4

ggplot(interros4, aes(y = score, x = test)) +
  geom_boxplot() +
  geom_jitter(aes(colour = height))+
  facet_grid(gender ~ group)

###QUESTIONS
#1 : Complete the following function that converts meters to yards, 
# knowing that that 1 yard corresponds to 0.9144 meters

meters_to_yards <- function(x) {
  yards <- (1/0.9144)*x
  return(yards)
}

meters_to_yards(25) #returns to be 27,3 yards
#searching on the internet, we can find it is indeed 27.3 yards so its OK



